build

Function build 

pub fn build<P: AsRef<Path>>(path: P)
Builds the native library rooted at path with the default xmake options. This will return the directory in which the library was installed.

Examples

use xmake;

// Builds the project in the directory located in `libfoo`, and link it
xmake::build("libfoo");