pub struct Link { /* private fields */ }Expand description
Represents a single linked library.
The Link struct contains information about a single linked library, including its name and the kind of linkage.
Implementations